package jdk.internal.jshell.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "20.0.2+9-78" },
            { "jdk", "20.0.2" },
            { "release", "20.0.2" },
        };
    }
}
